@@ -1,10 +1,8 @@
-{-# OPTIONS -fglasgow-exts #-}
-
 module Builders (tests) where
 
--- Testing Data.Generics.Builders functionality 
+-- Testing Data.Generics.Builders functionality
 
-import Test.HUnit
+import Test.Tasty.HUnit
 
 import Data.Data
 import Data.Generics.Builders
@@ -13,8 +11,8 @@ import Data.Generics.Builders
 -- Main function for testing
 tests = ( constrs :: [Maybe Int]
         , constrs :: [String]
-        , constrs :: [Either Int Float]
+        , constrs :: [Either Int Double]
         , constrs :: [((), Integer)]
-        ) ~=? output
+        ) @=? output
 
-output = ([Nothing,Just 0],["","\NUL"],[Left 0,Right 0.0],[((),0)])
\ No newline at end of file
+output = ([Nothing,Just 0],["","\NUL"],[Left 0,Right 0.0],[((),0)])
