@@ -1,5 +1,6 @@
-{-# OPTIONS -fglasgow-exts #-}
-{-# LANGUAGE CPP #-}
+{-# LANGUAGE CPP        #-}
+{-# LANGUAGE MagicHash  #-}
+{-# LANGUAGE RankNTypes #-}
 
 module Ext1 (tests) where
 
@@ -9,9 +10,10 @@ This example records some experiments with polymorphic datatypes.
 
 -}
 
-import Test.HUnit
+import Test.Tasty.HUnit
 
 import Data.Generics
+import GHC.Exts (unsafeCoerce#)
 #if MIN_VERSION_base(4,8,0)
 import GHC.Base hiding(foldr)
 #else
@@ -36,7 +38,7 @@ extListQ' :: Data d
 extListQ' def ext d =
   if isList d
     then ext (unsafeCoerce d)
-    else def d 
+    else def d
 
 
 -- Test extListQ'
@@ -54,7 +56,7 @@ extListQ'' :: Data d
 extListQ'' def ext d =
   if isList d
     then undefined -- hard to avoid an ambiguous type
-    else def d 
+    else def d
 
 
 -- Test extListQ from Data.Generics.Aliases
@@ -97,7 +99,7 @@ isCons x = toConstr x == toConstr (():[])
 -- gmapQ for polymorphic lists
 gmapListQ :: forall a q. Data a => (forall a. Data a => a -> q) -> a -> [q]
 gmapListQ f x =
-  if not $ isList x 
+  if not $ isList x
     then error "gmapListQ"
     else if isNil x
            then []
@@ -123,6 +125,6 @@ tests = ( t1
         , ( t4
         , ( t5
         , ( t6
-        )))))) ~=? output
+        )))))) @=? output
 
 output = (0,(2,(0,(4,(0,4)))))
