@@ -1,20 +1,20 @@
-{-# OPTIONS -fglasgow-exts #-}
+{-# LANGUAGE DeriveDataTypeable #-}
 
 module Labels (tests) where
 
 -- This module tests availability of field labels.
 
-import Test.HUnit
+import Test.Tasty.HUnit
 
 import Data.Generics
 
 -- A datatype without labels
-data NoLabels = NoLabels Int Float
+data NoLabels = NoLabels Int Double
               deriving (Typeable, Data)
 
 -- A datatype with labels
 data YesLabels = YesLabels { myint   :: Int
-                           , myfloat :: Float
+                           , myfloat :: Double
                            }
                deriving (Typeable, Data)
 
@@ -25,6 +25,6 @@ yesLabels = YesLabels 42 3.14
 -- Main function for testing
 tests = ( constrFields $ toConstr noLabels
         , constrFields $ toConstr yesLabels
-        ) ~=? output
+        ) @=? output
 
 output = ([],["myint","myfloat"])
