@@ -1,4 +1,7 @@
-{-# OPTIONS -fglasgow-exts #-}
+
+{-# LANGUAGE DeriveDataTypeable  #-}
+{-# LANGUAGE RankNTypes          #-}
+{-# LANGUAGE ScopedTypeVariables #-}
 
 module Reify (tests) where
 
@@ -10,7 +13,7 @@ types and constructors as means to steer the generation.
 
 -}
 
-import Test.HUnit
+import Test.Tasty.HUnit
 
 import Data.Maybe
 import Data.Generics
@@ -92,7 +95,7 @@ type TypeFun a r = TypeVal a -> r
 -- Generic type functions,
 -- i.e., functions mapping types to values
 --
-type GTypeFun r  = forall a. Data a => TypeFun a r
+type GTypeFun r = forall a. Data a => TypeFun a r
 
 
 
@@ -354,7 +357,7 @@ shallowTerm cust
 -- For testing shallowTerm
 shallowTermBase :: GenericR Maybe
 shallowTermBase =        Nothing
-                  `extR` Just (1.23::Float)
+                  `extR` Just (1.23::Double)
                   `extR` Just ("foo"::String)
 
 
@@ -406,7 +409,7 @@ tests = (   test0
         , ( test8
         , ( test9
         , ( test10
-        ))))))))))) ~=? output
+        ))))))))))) @=? output
 
 output = (True,(True,(False,(True,(True,(1,(2,(3,(P "foo" "foo",
            (E (P "foo" "foo") (S 1.23),
